package com.snowtide.pdf.test;

import com.snowtide.util.logging.Log;
import com.snowtide.util.logging.LoggingRegistry;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.StringWriter;

import org.pdfbox.pdfparser.PDFParser;
import org.pdfbox.pdmodel.PDDocument;
import org.pdfbox.util.PDFTextStripper;

/**
 * TestPerformance subclass dedicated to benchmarking the PDFBox
 * library.
 *
 * @version ©2004-2007 Snowtide Informatics Systems, Inc.
 */
public class TestPDFBoxPerformance extends TestPerformance {
    private static final Log log = LoggingRegistry.getLog(TestPDFBoxPerformance.class);

    public static void main (String[] args) throws Exception {
        new TestPDFBoxPerformance().runTest(args);
    }

    public String getLibraryId () {
        return "pdfbox";
    }

    /**
     * These are the guts of the main method of org.pdfbox.ExtractText.  It has been slimmed down to provide
     * optimum performance, to output the text into the given StringWriter, and to read the metadata out of the pdf.
     */
    public void extractText (File pdfFile, StringWriter output) throws Exception {
        InputStream input = null;
        PDDocument document = null;

        try {
            input = new FileInputStream(pdfFile);
            PDFParser parser = new PDFParser(input);
            parser.parse();
            document = parser.getPDDocument();

            PDFTextStripper stripper = new PDFTextStripper();
            stripper.setStartPage(1);
            stripper.setEndPage(Integer.MAX_VALUE);
            stripper.writeText(document, output);
        } finally {
            if (input != null) {
                input.close();
            }
            if (output != null) {
                output.close();
            }
            if (document != null) {
                document.close();
            }
        }
    }
}
